A dataset containing the daily closing price of 50 NYSE stocks from 2015-01-02 to 2016-12-30. The first 50 columns are the daily closing price for each of the 50 stocks, and the last column is the date.
financeA data frame with 504 rows and 51 variables:
The abbreviation for the 50 stocks are as follows: "AMD","BAC","AAPL","FTR","BBRY","GE","RAD","MU","CHK","F", "VALE","FCX","PBR","XOM","INTC","MSFT","WWAV","QQQ","ABEV", "VZ","HPQ","KKFC","PFE","SWN","T","AKS","FCAU","JPM","SFUN", "LULU","MT","WFT","CLF","SNA","S","C","HCP","DRYS","FMC", "CSCO","KMI","AES","X","SIRI","WLL","COP","BSX","JCP","RF","EDUC"