Learn R Programming

rarhsmm (version 1.0.7)

mvdnorm: multivariate normal density

Description

multivariate normal density

Usage

mvdnorm(x, mean, sigma, logd)

Arguments

x

matrix with each row as an observed vector of multivariate normal RVs

mean

vector of means

sigma

variance-covariance matrix

logd

whether log transformation should be used

Value

a vector of density values for each observed vector